
CHANGELOG
=========

0.3.5 (2019-01-21)
------------------

* Remove unused reference to ``cStringIO``.


0.3.4 (2017-07-07)
------------------

* Switch license to GPL v3 (no longer Affero)


0.3.3
-----

* Refactor some config usage per rattail changes.


0.3.2
-----

* Fix broken barcode commands.
    
  UPC wasn't working, and EAN wasn't even being attempted...


0.3.1
-----

* Refactor ``rattail.hw.cognitive`` -> ``rattail_cognitive``.


0.3a3
-----

- [general] Fixed namespace package declaration.

- [general] Added initial Fabric script.


0.3a2
-----

- Tweaked default label format.

0.3a1
-----

-  Initial port to Rattail v0.3.
